@@ -3,7 +3,7 @@ from herre.wards.graphql import ParsedQuery
 
 CREATE_TABLE = ParsedQuery(
     """
-mutation CreateTable($sample: ID, $name: String, $tags: [String], $creator: String, $rep: ID, $exp: ID){
+mutation CreateTable($sample: ID, $name: String, $tags: [String], $creator: String, $representation: ID, $experiment: ID){
   createTable(sample: $sample, name: $name, rep: $rep, exp: $exp, tags: $tags, creator: $creator){
     name
     id
