@@ -1,27 +1,32 @@
-
+from fakts import Fakts, get_current_fakts, Config
+from herre.herre import Herre
 from herre.wards.query import TypedQuery
 from herre.access.object import GraphQLObject
-from herre.config.herre import BaseConfig
-from herre.auth import HerreClient, get_current_herre
+from herre import get_current_herre
 from herre.wards.graphql import ParsedQuery, GraphQLWard
 import aiohttp
 import xarray as xr
 
 
-class MikroConfig(BaseConfig):
+class MikroConfig(Config):
     host: str
     port: int
     secure: bool
 
     class Config:
-        yaml_group = "mikro"
+        group = "mikro"
         env_prefix = "mikro_"
 
+    @property
+    def endpoint(self):
+        return f"http://{self.host}:{self.port}/graphql"
+
 
 class AccessParams(GraphQLObject):
     access_key: str
     secret_key: str
 
+
 class Transcript(GraphQLObject):
     protocol: str
     path: str
@@ -29,29 +34,25 @@ class Transcript(GraphQLObject):
 
 
 class MikroWard(GraphQLWard):
+    configClass = MikroConfig
 
     class Meta:
         key = "mikro"
 
-    def __init__(self, herre: HerreClient) -> None:
-        self.config = MikroConfig.from_file(herre.config_path)
-        self.transcript: Transcript = None
-        super().__init__(herre, f"http://{self.config.host}:{self.config.port}/graphql")
-
-
     async def negotiate(self):
-        transcript_query = await self.run(ParsedQuery("""mutation Negotiate {
+        transcript_query = await self.arun(
+            ParsedQuery(
+                """mutation Negotiate {
             negotiate 
-        }"""))
+        }"""
+            )
+        )
         return Transcript(**transcript_query["negotiate"])
 
 
-
-class playground():
-
+class playground:
     def __init__(self, width=900, height=700) -> None:
         herre = get_current_herre()
-        self.config = MikroConfig.from_file(herre.config_path)
         self.width = width
         self.height = height
 
@@ -59,9 +60,5 @@ class playground():
         return f"<iframe src='http://{self.config.host}:{self.config.port}/graphql' width={self.width} height={self.height}></iframe>"
 
 
-
 class gql(TypedQuery):
     ward_key = "mikro"
-    
-
-
